# PiSoftwareUpdatePayloadRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**wic_tarball_url** | **str** |  | 
**wic_bmap_url** | **str** |  | 
**manifest_url** | **str** |  | 
**swu_url** | **str** |  | 
**version_id** | **str** |  | 
**version** | **str** |  | 
**version_codename** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


